import json

import requests

from . import traffic

API_URI = "https://api.agilicus.com"


def get_gateway_generate(**kwargs):
    token = traffic.get_traffic_token(**kwargs)

    headers = {}
    headers["Accept"] = "text/plain"
    headers["Content-type"] = "application/json"

    data = {}
    data["token"] = token

    api = API_URI + "/deployment/local-gateway-k8s/generate"
    response = requests.post(api, headers=headers, data=json.dumps(data))
    return response.text



"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2022.08.11
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from agilicus_api.api_client import ApiClient, Endpoint as _Endpoint
from agilicus_api.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from agilicus_api.model.csr_reason_enum import CSRReasonEnum
from agilicus_api.model.cert_signing_req import CertSigningReq
from agilicus_api.model.error_message import ErrorMessage
from agilicus_api.model.inline_response200 import InlineResponse200
from agilicus_api.model.list_cert_signing_req_response import ListCertSigningReqResponse
from agilicus_api.model.list_x509_certificate_response import ListX509CertificateResponse
from agilicus_api.model.x509_certificate import X509Certificate


class CertificatesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __create_cert(
            self,
            x509_certificate,
            **kwargs
        ):
            """Creates a X509Certificate  # noqa: E501

            Creates a X509Certificate   # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_cert(x509_certificate, async_req=True)
            >>> result = thread.get()

            Args:
                x509_certificate (X509Certificate):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                X509Certificate
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['x509_certificate'] = \
                x509_certificate
            return self.call_with_http_info(**kwargs)

        if self.create_cert is None:
            self.create_cert = _Endpoint(
                settings={
                    'response_type': (X509Certificate,),
                    'auth': [
                        'token-valid'
                    ],
                    'endpoint_path': '/v1/certificates',
                    'operation_id': 'create_cert',
                    'http_method': 'POST',
                    'servers': None,
                },
                params_map={
                    'all': [
                        'x509_certificate',
                    ],
                    'required': [
                        'x509_certificate',
                    ],
                    'nullable': [
                    ],
                    'enum': [
                    ],
                    'validation': [
                    ]
                },
                root_map={
                    'validations': {
                    },
                    'allowed_values': {
                    },
                    'openapi_types': {
                        'x509_certificate':
                            (X509Certificate,),
                    },
                    'attribute_map': {
                    },
                    'location_map': {
                        'x509_certificate': 'body',
                    },
                    'collection_format_map': {
                    }
                },
                headers_map={
                    'accept': [
                        'application/json'
                    ],
                    'content_type': [
                        'application/json'
                    ]
                },
                api_client=api_client,
                callable=__create_cert
            )

        def __delete_agent_csr(
            self,
            connector_id,
            csr_id,
            **kwargs
        ):
            """Delete a CertSigningReq  # noqa: E501

            Delete a CertSigningReq  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_agent_csr(connector_id, csr_id, async_req=True)
            >>> result = thread.get()

            Args:
                connector_id (str): connector id path
                csr_id (str): A certificate signing request id

            Keyword Args:
                org_id (str): Organisation Unique identifier. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['connector_id'] = \
                connector_id
            kwargs['csr_id'] = \
                csr_id
            return self.call_with_http_info(**kwargs)

        if self.delete_agent_csr is None:
            self.delete_agent_csr = _Endpoint(
                settings={
                    'response_type': None,
                    'auth': [
                        'token-valid'
                    ],
                    'endpoint_path': '/v1/agent_connectors/{connector_id}/certificate_signing_requests/{csr_id}',
                    'operation_id': 'delete_agent_csr',
                    'http_method': 'DELETE',
                    'servers': None,
                },
                params_map={
                    'all': [
                        'connector_id',
                        'csr_id',
                        'org_id',
                    ],
                    'required': [
                        'connector_id',
                        'csr_id',
                    ],
                    'nullable': [
                    ],
                    'enum': [
                    ],
                    'validation': [
                    ]
                },
                root_map={
                    'validations': {
                    },
                    'allowed_values': {
                    },
                    'openapi_types': {
                        'connector_id':
                            (str,),
                        'csr_id':
                            (str,),
                        'org_id':
                            (str,),
                    },
                    'attribute_map': {
                        'connector_id': 'connector_id',
                        'csr_id': 'csr_id',
                        'org_id': 'org_id',
                    },
                    'location_map': {
                        'connector_id': 'path',
                        'csr_id': 'path',
                        'org_id': 'query',
                    },
                    'collection_format_map': {
                    }
                },
                headers_map={
                    'accept': [],
                    'content_type': [],
                },
                api_client=api_client,
                callable=__delete_agent_csr
            )

        def __delete_cert(
            self,
            certificate_id,
            **kwargs
        ):
            """Delete a X509Certificate  # noqa: E501

            Delete a X509Certificate  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_cert(certificate_id, async_req=True)
            >>> result = thread.get()

            Args:
                certificate_id (str): A certificate id

            Keyword Args:
                org_id (str): Organisation Unique identifier. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['certificate_id'] = \
                certificate_id
            return self.call_with_http_info(**kwargs)

        if self.delete_cert is None:
            self.delete_cert = _Endpoint(
                settings={
                    'response_type': None,
                    'auth': [
                        'token-valid'
                    ],
                    'endpoint_path': '/v1/certificates/{certificate_id}',
                    'operation_id': 'delete_cert',
                    'http_method': 'DELETE',
                    'servers': None,
                },
                params_map={
                    'all': [
                        'certificate_id',
                        'org_id',
                    ],
                    'required': [
                        'certificate_id',
                    ],
                    'nullable': [
                    ],
                    'enum': [
                    ],
                    'validation': [
                    ]
                },
                root_map={
                    'validations': {
                    },
                    'allowed_values': {
                    },
                    'openapi_types': {
                        'certificate_id':
                            (str,),
                        'org_id':
                            (str,),
                    },
                    'attribute_map': {
                        'certificate_id': 'certificate_id',
                        'org_id': 'org_id',
                    },
                    'location_map': {
                        'certificate_id': 'path',
                        'org_id': 'query',
                    },
                    'collection_format_map': {
                    }
                },
                headers_map={
                    'accept': [],
                    'content_type': [],
                },
                api_client=api_client,
                callable=__delete_cert
            )

        def __delete_csr(
            self,
            csr_id,
            **kwargs
        ):
            """Delete a CertSigningReq  # noqa: E501

            Delete a CertSigningReq  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_csr(csr_id, async_req=True)
            >>> result = thread.get()

            Args:
                csr_id (str): A certificate signing request id

            Keyword Args:
                org_id (str): Organisation Unique identifier. [optional]
                private_key_id (str): query by private key id. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['csr_id'] = \
                csr_id
            return self.call_with_http_info(**kwargs)

        if self.delete_csr is None:
            self.delete_csr = _Endpoint(
                settings={
                    'response_type': None,
                    'auth': [
                        'token-valid'
                    ],
                    'endpoint_path': '/v1/certificate_signing_requests/{csr_id}',
                    'operation_id': 'delete_csr',
                    'http_method': 'DELETE',
                    'servers': None,
                },
                params_map={
                    'all': [
                        'csr_id',
                        'org_id',
                        'private_key_id',
                    ],
                    'required': [
                        'csr_id',
                    ],
                    'nullable': [
                    ],
                    'enum': [
                    ],
                    'validation': [
                    ]
                },
                root_map={
                    'validations': {
                    },
                    'allowed_values': {
                    },
                    'openapi_types': {
                        'csr_id':
                            (str,),
                        'org_id':
                            (str,),
                        'private_key_id':
                            (str,),
                    },
                    'attribute_map': {
                        'csr_id': 'csr_id',
                        'org_id': 'org_id',
                        'private_key_id': 'private_key_id',
                    },
                    'location_map': {
                        'csr_id': 'path',
                        'org_id': 'query',
                        'private_key_id': 'query',
                    },
                    'collection_format_map': {
                    }
                },
                headers_map={
                    'accept': [],
                    'content_type': [],
                },
                api_client=api_client,
                callable=__delete_csr
            )

        def __get_cert(
            self,
            certificate_id,
            **kwargs
        ):
            """Get a X509Certificate  # noqa: E501

            Get a X509Certificate  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_cert(certificate_id, async_req=True)
            >>> result = thread.get()

            Args:
                certificate_id (str): A certificate id

            Keyword Args:
                org_id (str): Organisation Unique identifier. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                X509Certificate
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['certificate_id'] = \
                certificate_id
            return self.call_with_http_info(**kwargs)

        if self.get_cert is None:
            self.get_cert = _Endpoint(
                settings={
                    'response_type': (X509Certificate,),
                    'auth': [
                        'token-valid'
                    ],
                    'endpoint_path': '/v1/certificates/{certificate_id}',
                    'operation_id': 'get_cert',
                    'http_method': 'GET',
                    'servers': None,
                },
                params_map={
                    'all': [
                        'certificate_id',
                        'org_id',
                    ],
                    'required': [
                        'certificate_id',
                    ],
                    'nullable': [
                    ],
                    'enum': [
                    ],
                    'validation': [
                    ]
                },
                root_map={
                    'validations': {
                    },
                    'allowed_values': {
                    },
                    'openapi_types': {
                        'certificate_id':
                            (str,),
                        'org_id':
                            (str,),
                    },
                    'attribute_map': {
                        'certificate_id': 'certificate_id',
                        'org_id': 'org_id',
                    },
                    'location_map': {
                        'certificate_id': 'path',
                        'org_id': 'query',
                    },
                    'collection_format_map': {
                    }
                },
                headers_map={
                    'accept': [
                        'application/json'
                    ],
                    'content_type': [],
                },
                api_client=api_client,
                callable=__get_cert
            )

        def __get_csr(
            self,
            csr_id,
            **kwargs
        ):
            """Get a CertSigningReq  # noqa: E501

            Get a CertSigningReq  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_csr(csr_id, async_req=True)
            >>> result = thread.get()

            Args:
                csr_id (str): A certificate signing request id

            Keyword Args:
                org_id (str): Organisation Unique identifier. [optional]
                private_key_id (str): query by private key id. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CertSigningReq
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['csr_id'] = \
                csr_id
            return self.call_with_http_info(**kwargs)

        if self.get_csr is None:
            self.get_csr = _Endpoint(
                settings={
                    'response_type': (CertSigningReq,),
                    'auth': [
                        'token-valid'
                    ],
                    'endpoint_path': '/v1/certificate_signing_requests/{csr_id}',
                    'operation_id': 'get_csr',
                    'http_method': 'GET',
                    'servers': None,
                },
                params_map={
                    'all': [
                        'csr_id',
                        'org_id',
                        'private_key_id',
                    ],
                    'required': [
                        'csr_id',
                    ],
                    'nullable': [
                    ],
                    'enum': [
                    ],
                    'validation': [
                    ]
                },
                root_map={
                    'validations': {
                    },
                    'allowed_values': {
                    },
                    'openapi_types': {
                        'csr_id':
                            (str,),
                        'org_id':
                            (str,),
                        'private_key_id':
                            (str,),
                    },
                    'attribute_map': {
                        'csr_id': 'csr_id',
                        'org_id': 'org_id',
                        'private_key_id': 'private_key_id',
                    },
                    'location_map': {
                        'csr_id': 'path',
                        'org_id': 'query',
                        'private_key_id': 'query',
                    },
                    'collection_format_map': {
                    }
                },
                headers_map={
                    'accept': [
                        'application/json'
                    ],
                    'content_type': [],
                },
                api_client=api_client,
                callable=__get_csr
            )

        def __list_certs(
            self,
            **kwargs
        ):
            """list certificates  # noqa: E501

            List certificates   # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_certs(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): limit the number of rows in the response. [optional] if omitted the server will use the default value of 500
                org_id (str): Organisation Unique identifier. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListX509CertificateResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        if self.list_certs is None:
            self.list_certs = _Endpoint(
                settings={
                    'response_type': (ListX509CertificateResponse,),
                    'auth': [
                        'token-valid'
                    ],
                    'endpoint_path': '/v1/certificates',
                    'operation_id': 'list_certs',
                    'http_method': 'GET',
                    'servers': None,
                },
                params_map={
                    'all': [
                        'limit',
                        'org_id',
                    ],
                    'required': [],
                    'nullable': [
                    ],
                    'enum': [
                    ],
                    'validation': [
                        'limit',
                    ]
                },
                root_map={
                    'validations': {
                        ('limit',): {

                            'inclusive_maximum': 500,
                            'inclusive_minimum': 1,
                        },
                    },
                    'allowed_values': {
                    },
                    'openapi_types': {
                        'limit':
                            (int,),
                        'org_id':
                            (str,),
                    },
                    'attribute_map': {
                        'limit': 'limit',
                        'org_id': 'org_id',
                    },
                    'location_map': {
                        'limit': 'query',
                        'org_id': 'query',
                    },
                    'collection_format_map': {
                    }
                },
                headers_map={
                    'accept': [
                        'application/json'
                    ],
                    'content_type': [],
                },
                api_client=api_client,
                callable=__list_certs
            )

        def __list_csr(
            self,
            **kwargs
        ):
            """list certificate signing requests  # noqa: E501

            List certificate signing requests.   # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_csr(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): limit the number of rows in the response. [optional] if omitted the server will use the default value of 500
                org_id (str): Organisation Unique identifier. [optional]
                reason (CSRReasonEnum): Query a CSR based on its reason status. [optional]
                not_valid_after (str): Search criteria for finding expired certificates * In UTC. * Supports human-friendly values. * Example, find all expired certificates in 30 days: not_after_after=\"in 30 days\" * Example, find all expired certificates today:  not_valid_after=\"tomorrow\" * Example, find all expired now:  not_valid_after=\"now\" . [optional]
                target_issuer ([str]): A list of target issuers to search for. If an item matches an entry in the list, is returned. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListCertSigningReqResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        if self.list_csr is None:
            self.list_csr = _Endpoint(
                settings={
                    'response_type': (ListCertSigningReqResponse,),
                    'auth': [
                        'token-valid'
                    ],
                    'endpoint_path': '/v1/certificate_signing_requests',
                    'operation_id': 'list_csr',
                    'http_method': 'GET',
                    'servers': None,
                },
                params_map={
                    'all': [
                        'limit',
                        'org_id',
                        'reason',
                        'not_valid_after',
                        'target_issuer',
                    ],
                    'required': [],
                    'nullable': [
                    ],
                    'enum': [
                    ],
                    'validation': [
                        'limit',
                    ]
                },
                root_map={
                    'validations': {
                        ('limit',): {

                            'inclusive_maximum': 500,
                            'inclusive_minimum': 1,
                        },
                    },
                    'allowed_values': {
                    },
                    'openapi_types': {
                        'limit':
                            (int,),
                        'org_id':
                            (str,),
                        'reason':
                            (CSRReasonEnum,),
                        'not_valid_after':
                            (str,),
                        'target_issuer':
                            ([str],),
                    },
                    'attribute_map': {
                        'limit': 'limit',
                        'org_id': 'org_id',
                        'reason': 'reason',
                        'not_valid_after': 'not_valid_after',
                        'target_issuer': 'target_issuer',
                    },
                    'location_map': {
                        'limit': 'query',
                        'org_id': 'query',
                        'reason': 'query',
                        'not_valid_after': 'query',
                        'target_issuer': 'query',
                    },
                    'collection_format_map': {
                        'target_issuer': 'multi',
                    }
                },
                headers_map={
                    'accept': [
                        'application/json'
                    ],
                    'content_type': [],
                },
                api_client=api_client,
                callable=__list_csr
            )

        def __list_root_certs(
            self,
            **kwargs
        ):
            """list root certificates  # noqa: E501

            List the root certificates an organsation should trust when interacting with the local resources exposed by the Agilicus platform.   # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.list_root_certs(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): limit the number of rows in the response. [optional] if omitted the server will use the default value of 500
                org_id (str): Organisation Unique identifier. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                InlineResponse200
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        if self.list_root_certs is None:
            self.list_root_certs = _Endpoint(
                settings={
                    'response_type': (InlineResponse200,),
                    'auth': [
                        'token-valid'
                    ],
                    'endpoint_path': '/v1/root_certificates',
                    'operation_id': 'list_root_certs',
                    'http_method': 'GET',
                    'servers': None,
                },
                params_map={
                    'all': [
                        'limit',
                        'org_id',
                    ],
                    'required': [],
                    'nullable': [
                    ],
                    'enum': [
                    ],
                    'validation': [
                        'limit',
                    ]
                },
                root_map={
                    'validations': {
                        ('limit',): {

                            'inclusive_maximum': 500,
                            'inclusive_minimum': 1,
                        },
                    },
                    'allowed_values': {
                    },
                    'openapi_types': {
                        'limit':
                            (int,),
                        'org_id':
                            (str,),
                    },
                    'attribute_map': {
                        'limit': 'limit',
                        'org_id': 'org_id',
                    },
                    'location_map': {
                        'limit': 'query',
                        'org_id': 'query',
                    },
                    'collection_format_map': {
                    }
                },
                headers_map={
                    'accept': [
                        'application/json'
                    ],
                    'content_type': [],
                },
                api_client=api_client,
                callable=__list_root_certs
            )

        def __replace_csr(
            self,
            csr_id,
            **kwargs
        ):
            """Update a CertSigningReq  # noqa: E501

            Update a CertSigningReq  # noqa: E501
            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.replace_csr(csr_id, async_req=True)
            >>> result = thread.get()

            Args:
                csr_id (str): A certificate signing request id

            Keyword Args:
                org_id (str): Organisation Unique identifier. [optional]
                private_key_id (str): query by private key id. [optional]
                cert_signing_req (CertSigningReq): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (float/tuple): timeout setting for this request. If one
                    number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CertSigningReq
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['csr_id'] = \
                csr_id
            return self.call_with_http_info(**kwargs)

        if self.replace_csr is None:
            self.replace_csr = _Endpoint(
                settings={
                    'response_type': (CertSigningReq,),
                    'auth': [
                        'token-valid'
                    ],
                    'endpoint_path': '/v1/certificate_signing_requests/{csr_id}',
                    'operation_id': 'replace_csr',
                    'http_method': 'PUT',
                    'servers': None,
                },
                params_map={
                    'all': [
                        'csr_id',
                        'org_id',
                        'private_key_id',
                        'cert_signing_req',
                    ],
                    'required': [
                        'csr_id',
                    ],
                    'nullable': [
                    ],
                    'enum': [
                    ],
                    'validation': [
                    ]
                },
                root_map={
                    'validations': {
                    },
                    'allowed_values': {
                    },
                    'openapi_types': {
                        'csr_id':
                            (str,),
                        'org_id':
                            (str,),
                        'private_key_id':
                            (str,),
                        'cert_signing_req':
                            (CertSigningReq,),
                    },
                    'attribute_map': {
                        'csr_id': 'csr_id',
                        'org_id': 'org_id',
                        'private_key_id': 'private_key_id',
                    },
                    'location_map': {
                        'csr_id': 'path',
                        'org_id': 'query',
                        'private_key_id': 'query',
                        'cert_signing_req': 'body',
                    },
                    'collection_format_map': {
                    }
                },
                headers_map={
                    'accept': [
                        'application/json'
                    ],
                    'content_type': [
                        'application/json'
                    ]
                },
                api_client=api_client,
                callable=__replace_csr
            )

    create_cert = None 
    delete_agent_csr = None 
    delete_cert = None 
    delete_csr = None 
    get_cert = None 
    get_csr = None 
    list_certs = None 
    list_csr = None 
    list_root_certs = None 
    replace_csr = None 



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from agilicus_api.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from agilicus_api.model.api_key import APIKey
from agilicus_api.model.api_key_introspect import APIKeyIntrospect
from agilicus_api.model.api_key_introspect_authorization_info import APIKeyIntrospectAuthorizationInfo
from agilicus_api.model.api_key_introspect_response import APIKeyIntrospectResponse
from agilicus_api.model.api_key_op_status import APIKeyOpStatus
from agilicus_api.model.api_key_spec import APIKeySpec
from agilicus_api.model.api_key_status import APIKeyStatus
from agilicus_api.model.access_requests import AccessRequests
from agilicus_api.model.access_requests_status import AccessRequestsStatus
from agilicus_api.model.add_group_member_request import AddGroupMemberRequest
from agilicus_api.model.agent_connector import AgentConnector
from agilicus_api.model.agent_connector_authz_stats import AgentConnectorAuthzStats
from agilicus_api.model.agent_connector_cloud_routing import AgentConnectorCloudRouting
from agilicus_api.model.agent_connector_connection_info import AgentConnectorConnectionInfo
from agilicus_api.model.agent_connector_info import AgentConnectorInfo
from agilicus_api.model.agent_connector_local_bind import AgentConnectorLocalBind
from agilicus_api.model.agent_connector_local_bind_error import AgentConnectorLocalBindError
from agilicus_api.model.agent_connector_local_bind_stats import AgentConnectorLocalBindStats
from agilicus_api.model.agent_connector_per_share_stats import AgentConnectorPerShareStats
from agilicus_api.model.agent_connector_per_user_stats import AgentConnectorPerUserStats
from agilicus_api.model.agent_connector_proxy_request_stats import AgentConnectorProxyRequestStats
from agilicus_api.model.agent_connector_proxy_request_stats_details import AgentConnectorProxyRequestStatsDetails
from agilicus_api.model.agent_connector_proxy_stats import AgentConnectorProxyStats
from agilicus_api.model.agent_connector_queue import AgentConnectorQueue
from agilicus_api.model.agent_connector_queue_response import AgentConnectorQueueResponse
from agilicus_api.model.agent_connector_queue_spec import AgentConnectorQueueSpec
from agilicus_api.model.agent_connector_queue_status import AgentConnectorQueueStatus
from agilicus_api.model.agent_connector_routing_stats import AgentConnectorRoutingStats
from agilicus_api.model.agent_connector_share_stats import AgentConnectorShareStats
from agilicus_api.model.agent_connector_spec import AgentConnectorSpec
from agilicus_api.model.agent_connector_spec_provisioning import AgentConnectorSpecProvisioning
from agilicus_api.model.agent_connector_specific_stats import AgentConnectorSpecificStats
from agilicus_api.model.agent_connector_stats import AgentConnectorStats
from agilicus_api.model.agent_connector_status import AgentConnectorStatus
from agilicus_api.model.agent_connector_system_stats import AgentConnectorSystemStats
from agilicus_api.model.agent_connector_transport_stats import AgentConnectorTransportStats
from agilicus_api.model.agent_connector_tunnel_info import AgentConnectorTunnelInfo
from agilicus_api.model.agent_connector_user_stats import AgentConnectorUserStats
from agilicus_api.model.agent_local_auth_info import AgentLocalAuthInfo
from agilicus_api.model.allow_map_compiled import AllowMapCompiled
from agilicus_api.model.allow_rule_compiled import AllowRuleCompiled
from agilicus_api.model.application import Application
from agilicus_api.model.application_additional_context import ApplicationAdditionalContext
from agilicus_api.model.application_assignment import ApplicationAssignment
from agilicus_api.model.application_authentication_config import ApplicationAuthenticationConfig
from agilicus_api.model.application_config import ApplicationConfig
from agilicus_api.model.application_dynamic_config import ApplicationDynamicConfig
from agilicus_api.model.application_monitoring_config import ApplicationMonitoringConfig
from agilicus_api.model.application_security import ApplicationSecurity
from agilicus_api.model.application_service import ApplicationService
from agilicus_api.model.application_service_assignment import ApplicationServiceAssignment
from agilicus_api.model.application_service_load_balancing import ApplicationServiceLoadBalancing
from agilicus_api.model.application_service_location import ApplicationServiceLocation
from agilicus_api.model.application_service_route import ApplicationServiceRoute
from agilicus_api.model.application_service_routing_info import ApplicationServiceRoutingInfo
from agilicus_api.model.application_service_stats import ApplicationServiceStats
from agilicus_api.model.application_service_stats_group import ApplicationServiceStatsGroup
from agilicus_api.model.application_service_status import ApplicationServiceStatus
from agilicus_api.model.application_state_selector import ApplicationStateSelector
from agilicus_api.model.application_stats import ApplicationStats
from agilicus_api.model.application_stats_list import ApplicationStatsList
from agilicus_api.model.application_summary import ApplicationSummary
from agilicus_api.model.application_summary_status import ApplicationSummaryStatus
from agilicus_api.model.application_upstream_config import ApplicationUpstreamConfig
from agilicus_api.model.application_upstream_form_info import ApplicationUpstreamFormInfo
from agilicus_api.model.application_upstream_identity_provider import ApplicationUpstreamIdentityProvider
from agilicus_api.model.application_upstream_validation import ApplicationUpstreamValidation
from agilicus_api.model.audit import Audit
from agilicus_api.model.audit_attribute import AuditAttribute
from agilicus_api.model.audit_destination import AuditDestination
from agilicus_api.model.audit_destination_authentication import AuditDestinationAuthentication
from agilicus_api.model.audit_destination_filter import AuditDestinationFilter
from agilicus_api.model.audit_destination_spec import AuditDestinationSpec
from agilicus_api.model.audit_event import AuditEvent
from agilicus_api.model.audit_event_response import AuditEventResponse
from agilicus_api.model.audit_webhook_bulk_event import AuditWebhookBulkEvent
from agilicus_api.model.audit_webhook_events_processed import AuditWebhookEventsProcessed
from agilicus_api.model.auth_audits import AuthAudits
from agilicus_api.model.authentication_attribute import AuthenticationAttribute
from agilicus_api.model.authentication_document import AuthenticationDocument
from agilicus_api.model.authentication_document_spec import AuthenticationDocumentSpec
from agilicus_api.model.authentication_document_status import AuthenticationDocumentStatus
from agilicus_api.model.auto_create_status import AutoCreateStatus
from agilicus_api.model.base_upstream import BaseUpstream
from agilicus_api.model.base_upstreams import BaseUpstreams
from agilicus_api.model.billing_account import BillingAccount
from agilicus_api.model.billing_account_spec import BillingAccountSpec
from agilicus_api.model.billing_account_status import BillingAccountStatus
from agilicus_api.model.billing_customer import BillingCustomer
from agilicus_api.model.billing_org import BillingOrg
from agilicus_api.model.billing_portal_link import BillingPortalLink
from agilicus_api.model.billing_product import BillingProduct
from agilicus_api.model.billing_product_price import BillingProductPrice
from agilicus_api.model.billing_subscription import BillingSubscription
from agilicus_api.model.billing_usage_record import BillingUsageRecord
from agilicus_api.model.billing_usage_summary import BillingUsageSummary
from agilicus_api.model.bulk_session_operation_response import BulkSessionOperationResponse
from agilicus_api.model.bulk_token_revoke import BulkTokenRevoke
from agilicus_api.model.bulk_token_revoke_response import BulkTokenRevokeResponse
from agilicus_api.model.bulk_user_metadata import BulkUserMetadata
from agilicus_api.model.cors_origin import CORSOrigin
from agilicus_api.model.cors_settings import CORSSettings
from agilicus_api.model.csp_directive import CSPDirective
from agilicus_api.model.csp_settings import CSPSettings
from agilicus_api.model.csr_reason_enum import CSRReasonEnum
from agilicus_api.model.catalogue import Catalogue
from agilicus_api.model.catalogue_entry import CatalogueEntry
from agilicus_api.model.cert_signing_req import CertSigningReq
from agilicus_api.model.cert_signing_req_spec import CertSigningReqSpec
from agilicus_api.model.cert_signing_req_status import CertSigningReqStatus
from agilicus_api.model.certificate_transparency_settings import CertificateTransparencySettings
from agilicus_api.model.challenge import Challenge
from agilicus_api.model.challenge_answer import ChallengeAnswer
from agilicus_api.model.challenge_answer_spec import ChallengeAnswerSpec
from agilicus_api.model.challenge_endpoint import ChallengeEndpoint
from agilicus_api.model.challenge_spec import ChallengeSpec
from agilicus_api.model.challenge_status import ChallengeStatus
from agilicus_api.model.cipher_diffie_hellman_group import CipherDiffieHellmanGroup
from agilicus_api.model.cipher_encryption_algorithm import CipherEncryptionAlgorithm
from agilicus_api.model.cipher_integrity_algorithm import CipherIntegrityAlgorithm
from agilicus_api.model.combined_resource_rules import CombinedResourceRules
from agilicus_api.model.combined_resource_rules_status import CombinedResourceRulesStatus
from agilicus_api.model.combined_rules import CombinedRules
from agilicus_api.model.combined_rules_status import CombinedRulesStatus
from agilicus_api.model.combined_user_detail import CombinedUserDetail
from agilicus_api.model.combined_user_detail_status import CombinedUserDetailStatus
from agilicus_api.model.common_metadata import CommonMetadata
from agilicus_api.model.compound_rule_condition import CompoundRuleCondition
from agilicus_api.model.connector import Connector
from agilicus_api.model.connector_cloud_routing import ConnectorCloudRouting
from agilicus_api.model.connector_diagnostic_stats import ConnectorDiagnosticStats
from agilicus_api.model.connector_route import ConnectorRoute
from agilicus_api.model.connector_spec import ConnectorSpec
from agilicus_api.model.connector_stats import ConnectorStats
from agilicus_api.model.connector_stats_metadata import ConnectorStatsMetadata
from agilicus_api.model.connector_status import ConnectorStatus
from agilicus_api.model.connector_system_stats import ConnectorSystemStats
from agilicus_api.model.content_type_options_settings import ContentTypeOptionsSettings
from agilicus_api.model.create_billing_usage_records import CreateBillingUsageRecords
from agilicus_api.model.create_session_and_token_request import CreateSessionAndTokenRequest
from agilicus_api.model.create_session_and_token_response import CreateSessionAndTokenResponse
from agilicus_api.model.create_token_request import CreateTokenRequest
from agilicus_api.model.cross_origin_embedder_policy_settings import CrossOriginEmbedderPolicySettings
from agilicus_api.model.cross_origin_opener_policy_settings import CrossOriginOpenerPolicySettings
from agilicus_api.model.cross_origin_resource_policy_settings import CrossOriginResourcePolicySettings
from agilicus_api.model.definition import Definition
from agilicus_api.model.desktop_client_configuration import DesktopClientConfiguration
from agilicus_api.model.desktop_client_generated_configuration import DesktopClientGeneratedConfiguration
from agilicus_api.model.desktop_connection_info import DesktopConnectionInfo
from agilicus_api.model.desktop_resource import DesktopResource
from agilicus_api.model.desktop_resource_spec import DesktopResourceSpec
from agilicus_api.model.desktop_resource_stats import DesktopResourceStats
from agilicus_api.model.desktop_resource_status import DesktopResourceStatus
from agilicus_api.model.domain import Domain
from agilicus_api.model.email import Email
from agilicus_api.model.environment import Environment
from agilicus_api.model.environment_config import EnvironmentConfig
from agilicus_api.model.environment_config_var import EnvironmentConfigVar
from agilicus_api.model.environment_status import EnvironmentStatus
from agilicus_api.model.error_message import ErrorMessage
from agilicus_api.model.feature_flag import FeatureFlag
from agilicus_api.model.feature_tag import FeatureTag
from agilicus_api.model.feature_tag_name import FeatureTagName
from agilicus_api.model.feature_tag_spec import FeatureTagSpec
from agilicus_api.model.file import File
from agilicus_api.model.file_name import FileName
from agilicus_api.model.file_share_client_config import FileShareClientConfig
from agilicus_api.model.file_share_client_config_linux_config import FileShareClientConfigLinuxConfig
from agilicus_api.model.file_share_client_config_mac_config import FileShareClientConfigMacConfig
from agilicus_api.model.file_share_client_config_windows_config import FileShareClientConfigWindowsConfig
from agilicus_api.model.file_share_service import FileShareService
from agilicus_api.model.file_share_service_spec import FileShareServiceSpec
from agilicus_api.model.file_share_service_stats import FileShareServiceStats
from agilicus_api.model.file_share_service_stats_group import FileShareServiceStatsGroup
from agilicus_api.model.file_share_service_status import FileShareServiceStatus
from agilicus_api.model.file_summary import FileSummary
from agilicus_api.model.file_visibility import FileVisibility
from agilicus_api.model.frame_options_settings import FrameOptionsSettings
from agilicus_api.model.generic_float_metric import GenericFloatMetric
from agilicus_api.model.generic_int_metric import GenericIntMetric
from agilicus_api.model.group import Group
from agilicus_api.model.group_data import GroupData
from agilicus_api.model.group_member import GroupMember
from agilicus_api.model.group_reconcile_record import GroupReconcileRecord
from agilicus_api.model.guid_metadata import GuidMetadata
from agilicus_api.model.hsts_settings import HSTSSettings
from agilicus_api.model.http_basic_auth import HTTPBasicAuth
from agilicus_api.model.http_bearer_auth import HTTPBearerAuth
from agilicus_api.model.http_security_settings import HTTPSecuritySettings
from agilicus_api.model.host_permissions import HostPermissions
from agilicus_api.model.http_request_extractor import HttpRequestExtractor
from agilicus_api.model.http_request_extractor_source import HttpRequestExtractorSource
from agilicus_api.model.http_rule import HttpRule
from agilicus_api.model.http_rule_condition import HttpRuleCondition
from agilicus_api.model.http_rule_condition_type import HttpRuleConditionType
from agilicus_api.model.identity_assertion import IdentityAssertion
from agilicus_api.model.identity_assertion_response import IdentityAssertionResponse
from agilicus_api.model.included_role import IncludedRole
from agilicus_api.model.inheritable_user_config import InheritableUserConfig
from agilicus_api.model.inline_response200 import InlineResponse200
from agilicus_api.model.interceptor_command import InterceptorCommand
from agilicus_api.model.interceptor_config import InterceptorConfig
from agilicus_api.model.ipsec_connection import IpsecConnection
from agilicus_api.model.ipsec_connection_ipv4_block import IpsecConnectionIpv4Block
from agilicus_api.model.ipsec_connection_spec import IpsecConnectionSpec
from agilicus_api.model.ipsec_connector import IpsecConnector
from agilicus_api.model.ipsec_connector_spec import IpsecConnectorSpec
from agilicus_api.model.ipsec_connector_status import IpsecConnectorStatus
from agilicus_api.model.ipsec_gateway_interface import IpsecGatewayInterface
from agilicus_api.model.issuer import Issuer
from agilicus_api.model.issuer_client import IssuerClient
from agilicus_api.model.issuer_upstream import IssuerUpstream
from agilicus_api.model.js_inject import JSInject
from agilicus_api.model.json_body_constraint import JSONBodyConstraint
from agilicus_api.model.jwks import JWKS
from agilicus_api.model.k8s_slug import K8sSlug
from agilicus_api.model.kerberos_upstream_config import KerberosUpstreamConfig
from agilicus_api.model.kerberos_upstream_identity_provider import KerberosUpstreamIdentityProvider
from agilicus_api.model.kerberos_upstream_status import KerberosUpstreamStatus
from agilicus_api.model.kerberos_upstream_status_key_tab_entries import KerberosUpstreamStatusKeyTabEntries
from agilicus_api.model.launcher import Launcher
from agilicus_api.model.launcher_config import LauncherConfig
from agilicus_api.model.launcher_spec import LauncherSpec
from agilicus_api.model.launcher_status import LauncherStatus
from agilicus_api.model.list_api_keys_response import ListAPIKeysResponse
from agilicus_api.model.list_access_requests_response import ListAccessRequestsResponse
from agilicus_api.model.list_active_users_response import ListActiveUsersResponse
from agilicus_api.model.list_agent_connector_response import ListAgentConnectorResponse
from agilicus_api.model.list_application_services_response import ListApplicationServicesResponse
from agilicus_api.model.list_application_summary_response import ListApplicationSummaryResponse
from agilicus_api.model.list_applications_response import ListApplicationsResponse
from agilicus_api.model.list_audit_destinations_response import ListAuditDestinationsResponse
from agilicus_api.model.list_audits_response import ListAuditsResponse
from agilicus_api.model.list_auth_audits_response import ListAuthAuditsResponse
from agilicus_api.model.list_authentication_document_response import ListAuthenticationDocumentResponse
from agilicus_api.model.list_billing_accounts_response import ListBillingAccountsResponse
from agilicus_api.model.list_billing_usage_records_response import ListBillingUsageRecordsResponse
from agilicus_api.model.list_catalogue_entries_response import ListCatalogueEntriesResponse
from agilicus_api.model.list_catalogues_response import ListCataloguesResponse
from agilicus_api.model.list_cert_signing_req_response import ListCertSigningReqResponse
from agilicus_api.model.list_combined_resource_rules_response import ListCombinedResourceRulesResponse
from agilicus_api.model.list_combined_rules_response import ListCombinedRulesResponse
from agilicus_api.model.list_combined_user_details_response import ListCombinedUserDetailsResponse
from agilicus_api.model.list_configs_response import ListConfigsResponse
from agilicus_api.model.list_connector_response import ListConnectorResponse
from agilicus_api.model.list_desktop_resources_response import ListDesktopResourcesResponse
from agilicus_api.model.list_domains_response import ListDomainsResponse
from agilicus_api.model.list_elevated_user_roles import ListElevatedUserRoles
from agilicus_api.model.list_environment_configs_response import ListEnvironmentConfigsResponse
from agilicus_api.model.list_feature_tags_response import ListFeatureTagsResponse
from agilicus_api.model.list_file_share_services_response import ListFileShareServicesResponse
from agilicus_api.model.list_files_response import ListFilesResponse
from agilicus_api.model.list_groups_response import ListGroupsResponse
from agilicus_api.model.list_guid_metadata_response import ListGuidMetadataResponse
from agilicus_api.model.list_ipsec_connector_response import ListIpsecConnectorResponse
from agilicus_api.model.list_issuer_clients_response import ListIssuerClientsResponse
from agilicus_api.model.list_issuer_extensions_response import ListIssuerExtensionsResponse
from agilicus_api.model.list_issuer_roots_response import ListIssuerRootsResponse
from agilicus_api.model.list_issuer_upstreams import ListIssuerUpstreams
from agilicus_api.model.list_jwks import ListJWKS
from agilicus_api.model.list_launchers_response import ListLaunchersResponse
from agilicus_api.model.list_logs_response import ListLogsResponse
from agilicus_api.model.list_mfa_challenge_methods import ListMFAChallengeMethods
from agilicus_api.model.list_message_endpoints_response import ListMessageEndpointsResponse
from agilicus_api.model.list_orgs_response import ListOrgsResponse
from agilicus_api.model.list_point_of_presences_response import ListPointOfPresencesResponse
from agilicus_api.model.list_policies_response import ListPoliciesResponse
from agilicus_api.model.list_policy_rules_response import ListPolicyRulesResponse
from agilicus_api.model.list_products_response import ListProductsResponse
from agilicus_api.model.list_resource_permissions_response import ListResourcePermissionsResponse
from agilicus_api.model.list_resource_roles_response import ListResourceRolesResponse
from agilicus_api.model.list_resources_response import ListResourcesResponse
from agilicus_api.model.list_role_to_rule_entries import ListRoleToRuleEntries
from agilicus_api.model.list_roles import ListRoles
from agilicus_api.model.list_rules import ListRules
from agilicus_api.model.list_ssh_resources_response import ListSSHResourcesResponse
from agilicus_api.model.list_secure_agent_response import ListSecureAgentResponse
from agilicus_api.model.list_service_account_response import ListServiceAccountResponse
from agilicus_api.model.list_service_forwarders_response import ListServiceForwardersResponse
from agilicus_api.model.list_sessions_response import ListSessionsResponse
from agilicus_api.model.list_totp_enrollment_response import ListTOTPEnrollmentResponse
from agilicus_api.model.list_tokens_response import ListTokensResponse
from agilicus_api.model.list_top_users_response import ListTopUsersResponse
from agilicus_api.model.list_upstream_aliases import ListUpstreamAliases
from agilicus_api.model.list_upstream_group_mapping import ListUpstreamGroupMapping
from agilicus_api.model.list_upstream_user_identities_response import ListUpstreamUserIdentitiesResponse
from agilicus_api.model.list_user_application_access_info_response import ListUserApplicationAccessInfoResponse
from agilicus_api.model.list_user_desktop_access_info_response import ListUserDesktopAccessInfoResponse
from agilicus_api.model.list_user_file_share_access_info_response import ListUserFileShareAccessInfoResponse
from agilicus_api.model.list_user_guids_response import ListUserGuidsResponse
from agilicus_api.model.list_user_launcher_access_info_response import ListUserLauncherAccessInfoResponse
from agilicus_api.model.list_user_metadata_response import ListUserMetadataResponse
from agilicus_api.model.list_user_request_info_response import ListUserRequestInfoResponse
from agilicus_api.model.list_user_resource_access_info_response import ListUserResourceAccessInfoResponse
from agilicus_api.model.list_user_roles_for_an_org import ListUserRolesForAnOrg
from agilicus_api.model.list_user_ssh_access_info_response import ListUserSSHAccessInfoResponse
from agilicus_api.model.list_users_response import ListUsersResponse
from agilicus_api.model.list_web_auth_n_enrollment_response import ListWebAuthNEnrollmentResponse
from agilicus_api.model.list_well_known_issuer_info import ListWellKnownIssuerInfo
from agilicus_api.model.list_x509_certificate_response import ListX509CertificateResponse
from agilicus_api.model.local_auth_upstream_config import LocalAuthUpstreamConfig
from agilicus_api.model.local_auth_upstream_identity_provider import LocalAuthUpstreamIdentityProvider
from agilicus_api.model.log import Log
from agilicus_api.model.login_session import LoginSession
from agilicus_api.model.lookup_request import LookupRequest
from agilicus_api.model.mfa_challenge_answer import MFAChallengeAnswer
from agilicus_api.model.mfa_challenge_answer_result import MFAChallengeAnswerResult
from agilicus_api.model.mfa_challenge_method import MFAChallengeMethod
from agilicus_api.model.mfa_challenge_method_spec import MFAChallengeMethodSpec
from agilicus_api.model.mfa_challenge_question import MFAChallengeQuestion
from agilicus_api.model.mfa_challenge_question_input import MFAChallengeQuestionInput
from agilicus_api.model.mfa_challenge_question_login_info import MFAChallengeQuestionLoginInfo
from agilicus_api.model.mfa_enrollment_answer import MFAEnrollmentAnswer
from agilicus_api.model.mfa_enrollment_answer_result import MFAEnrollmentAnswerResult
from agilicus_api.model.mfa_enrollment_question import MFAEnrollmentQuestion
from agilicus_api.model.mfa_enrollment_question_input import MFAEnrollmentQuestionInput
from agilicus_api.model.mfa_enrollment_question_login_info import MFAEnrollmentQuestionLoginInfo
from agilicus_api.model.managed_upstream_identity_provider import ManagedUpstreamIdentityProvider
from agilicus_api.model.many_org_token_introspect_response import ManyOrgTokenIntrospectResponse
from agilicus_api.model.map_attributes_answer import MapAttributesAnswer
from agilicus_api.model.map_attributes_answer_result import MapAttributesAnswerResult
from agilicus_api.model.map_attributes_question import MapAttributesQuestion
from agilicus_api.model.map_attributes_question_input import MapAttributesQuestionInput
from agilicus_api.model.map_attributes_question_login_info import MapAttributesQuestionLoginInfo
from agilicus_api.model.mapped_attributes import MappedAttributes
from agilicus_api.model.message import Message
from agilicus_api.model.message_action import MessageAction
from agilicus_api.model.message_endpoint import MessageEndpoint
from agilicus_api.model.message_endpoint_metadata import MessageEndpointMetadata
from agilicus_api.model.message_endpoint_spec import MessageEndpointSpec
from agilicus_api.model.message_endpoint_type import MessageEndpointType
from agilicus_api.model.message_endpoint_type_web_push import MessageEndpointTypeWebPush
from agilicus_api.model.message_endpoints_config import MessageEndpointsConfig
from agilicus_api.model.metadata_with_id import MetadataWithId
from agilicus_api.model.metadata_with_id_all_of import MetadataWithIdAllOf
from agilicus_api.model.metadata_with_only_id import MetadataWithOnlyId
from agilicus_api.model.network_mount_rule_config import NetworkMountRuleConfig
from agilicus_api.model.network_port import NetworkPort
from agilicus_api.model.network_port_range import NetworkPortRange
from agilicus_api.model.network_service_config import NetworkServiceConfig
from agilicus_api.model.next_page_email import NextPageEmail
from agilicus_api.model.oidc_auth_config import OIDCAuthConfig
from agilicus_api.model.oidc_auth_path_config import OIDCAuthPathConfig
from agilicus_api.model.oidc_auth_uri import OIDCAuthURI
from agilicus_api.model.oidc_content_type import OIDCContentType
from agilicus_api.model.oidc_proxy_config import OIDCProxyConfig
from agilicus_api.model.oidc_proxy_content_manipulation import OIDCProxyContentManipulation
from agilicus_api.model.oidc_proxy_domain_mapping import OIDCProxyDomainMapping
from agilicus_api.model.oidc_proxy_domain_name_mapping import OIDCProxyDomainNameMapping
from agilicus_api.model.oidc_proxy_domain_substitution import OIDCProxyDomainSubstitution
from agilicus_api.model.oidc_proxy_header import OIDCProxyHeader
from agilicus_api.model.oidc_proxy_header_mapping import OIDCProxyHeaderMapping
from agilicus_api.model.oidc_proxy_header_match import OIDCProxyHeaderMatch
from agilicus_api.model.oidc_proxy_header_name import OIDCProxyHeaderName
from agilicus_api.model.oidc_proxy_header_override import OIDCProxyHeaderOverride
from agilicus_api.model.oidc_proxy_header_rewrite_filter import OIDCProxyHeaderRewriteFilter
from agilicus_api.model.oidc_proxy_header_user_config import OIDCProxyHeaderUserConfig
from agilicus_api.model.oidc_proxy_scope import OIDCProxyScope
from agilicus_api.model.oidc_proxy_standard_header import OIDCProxyStandardHeader
from agilicus_api.model.oidc_proxy_upstream_authentication import OIDCProxyUpstreamAuthentication
from agilicus_api.model.oidc_proxy_upstream_config import OIDCProxyUpstreamConfig
from agilicus_api.model.oidc_proxy_upstream_ntlm import OIDCProxyUpstreamNTLM
from agilicus_api.model.oidc_upstream_identity_provider import OIDCUpstreamIdentityProvider
from agilicus_api.model.operational_status import OperationalStatus
from agilicus_api.model.org_info import OrgInfo
from agilicus_api.model.org_scope_patch_document import OrgScopePatchDocument
from agilicus_api.model.organisation import Organisation
from agilicus_api.model.organisation_admin import OrganisationAdmin
from agilicus_api.model.organisation_capabilities import OrganisationCapabilities
from agilicus_api.model.organisation_owner_config import OrganisationOwnerConfig
from agilicus_api.model.organisation_state_selector import OrganisationStateSelector
from agilicus_api.model.organisation_state_status import OrganisationStateStatus
from agilicus_api.model.organisation_status import OrganisationStatus
from agilicus_api.model.permitted_cross_domain_policies_settings import PermittedCrossDomainPoliciesSettings
from agilicus_api.model.point_of_presence import PointOfPresence
from agilicus_api.model.point_of_presence_routing import PointOfPresenceRouting
from agilicus_api.model.point_of_presence_spec import PointOfPresenceSpec
from agilicus_api.model.policy import Policy
from agilicus_api.model.policy_condition import PolicyCondition
from agilicus_api.model.policy_group import PolicyGroup
from agilicus_api.model.policy_group_spec import PolicyGroupSpec
from agilicus_api.model.policy_rule import PolicyRule
from agilicus_api.model.policy_rule_spec import PolicyRuleSpec
from agilicus_api.model.policy_spec import PolicySpec
from agilicus_api.model.previous_page_email import PreviousPageEmail
from agilicus_api.model.product import Product
from agilicus_api.model.product_spec import ProductSpec
from agilicus_api.model.product_status import ProductStatus
from agilicus_api.model.raw_token import RawToken
from agilicus_api.model.referrer_policy_settings import ReferrerPolicySettings
from agilicus_api.model.rendered_query_parameter import RenderedQueryParameter
from agilicus_api.model.rendered_resource_permissions import RenderedResourcePermissions
from agilicus_api.model.rendered_rule import RenderedRule
from agilicus_api.model.rendered_rule_body import RenderedRuleBody
from agilicus_api.model.replace_user_role_request import ReplaceUserRoleRequest
from agilicus_api.model.reset_mfa_challenge_method import ResetMFAChallengeMethod
from agilicus_api.model.reset_policy_request import ResetPolicyRequest
from agilicus_api.model.resource import Resource
from agilicus_api.model.resource_config import ResourceConfig
from agilicus_api.model.resource_info import ResourceInfo
from agilicus_api.model.resource_member import ResourceMember
from agilicus_api.model.resource_permission import ResourcePermission
from agilicus_api.model.resource_permission_spec import ResourcePermissionSpec
from agilicus_api.model.resource_role import ResourceRole
from agilicus_api.model.resource_role_spec import ResourceRoleSpec
from agilicus_api.model.resource_rule_group import ResourceRuleGroup
from agilicus_api.model.resource_session_stats import ResourceSessionStats
from agilicus_api.model.resource_spec import ResourceSpec
from agilicus_api.model.resource_stats import ResourceStats
from agilicus_api.model.resource_stats_metadata import ResourceStatsMetadata
from agilicus_api.model.resource_status import ResourceStatus
from agilicus_api.model.role import Role
from agilicus_api.model.role_config import RoleConfig
from agilicus_api.model.role_list import RoleList
from agilicus_api.model.role_spec import RoleSpec
from agilicus_api.model.role_to_rule_entry import RoleToRuleEntry
from agilicus_api.model.role_to_rule_entry_spec import RoleToRuleEntrySpec
from agilicus_api.model.role_v2 import RoleV2
from agilicus_api.model.roles import Roles
from agilicus_api.model.roles_config import RolesConfig
from agilicus_api.model.rule import Rule
from agilicus_api.model.rule_action import RuleAction
from agilicus_api.model.rule_condition import RuleCondition
from agilicus_api.model.rule_condition_base import RuleConditionBase
from agilicus_api.model.rule_config import RuleConfig
from agilicus_api.model.rule_match_criteria import RuleMatchCriteria
from agilicus_api.model.rule_matcher import RuleMatcher
from agilicus_api.model.rule_matcher_list import RuleMatcherList
from agilicus_api.model.rule_query_body import RuleQueryBody
from agilicus_api.model.rule_query_body_json import RuleQueryBodyJSON
from agilicus_api.model.rule_query_parameter import RuleQueryParameter
from agilicus_api.model.rule_scope_enum import RuleScopeEnum
from agilicus_api.model.rule_set import RuleSet
from agilicus_api.model.rule_set_component import RuleSetComponent
from agilicus_api.model.rule_set_node import RuleSetNode
from agilicus_api.model.rule_spec import RuleSpec
from agilicus_api.model.rule_v2 import RuleV2
from agilicus_api.model.rules_config import RulesConfig
from agilicus_api.model.runtime_status import RuntimeStatus
from agilicus_api.model.ssh_resource import SSHResource
from agilicus_api.model.ssh_resource_spec import SSHResourceSpec
from agilicus_api.model.ssh_resource_stats import SSHResourceStats
from agilicus_api.model.secure_agent import SecureAgent
from agilicus_api.model.secure_agent_connector import SecureAgentConnector
from agilicus_api.model.secure_agent_connector_info import SecureAgentConnectorInfo
from agilicus_api.model.secure_agent_spec import SecureAgentSpec
from agilicus_api.model.secure_agent_status import SecureAgentStatus
from agilicus_api.model.selector_tag import SelectorTag
from agilicus_api.model.service_account import ServiceAccount
from agilicus_api.model.service_account_reset_body import ServiceAccountResetBody
from agilicus_api.model.service_account_spec import ServiceAccountSpec
from agilicus_api.model.service_account_status import ServiceAccountStatus
from agilicus_api.model.service_forwarder import ServiceForwarder
from agilicus_api.model.service_forwarder_spec import ServiceForwarderSpec
from agilicus_api.model.service_forwarder_stats import ServiceForwarderStats
from agilicus_api.model.service_forwarder_stats_group import ServiceForwarderStatsGroup
from agilicus_api.model.service_forwarder_status import ServiceForwarderStatus
from agilicus_api.model.service_http_config import ServiceHttpConfig
from agilicus_api.model.service_protocol_config import ServiceProtocolConfig
from agilicus_api.model.session import Session
from agilicus_api.model.sessions_spec import SessionsSpec
from agilicus_api.model.source_iso_country_code_condition import SourceISOCountryCodeCondition
from agilicus_api.model.storage_region import StorageRegion
from agilicus_api.model.totp_enrollment import TOTPEnrollment
from agilicus_api.model.totp_enrollment_answer import TOTPEnrollmentAnswer
from agilicus_api.model.totp_enrollment_spec import TOTPEnrollmentSpec
from agilicus_api.model.totp_enrollment_status import TOTPEnrollmentStatus
from agilicus_api.model.template_extraction import TemplateExtraction
from agilicus_api.model.template_path import TemplatePath
from agilicus_api.model.time_interval_metrics import TimeIntervalMetrics
from agilicus_api.model.time_validity import TimeValidity
from agilicus_api.model.token import Token
from agilicus_api.model.token_introspect import TokenIntrospect
from agilicus_api.model.token_introspect_options import TokenIntrospectOptions
from agilicus_api.model.token_reissue_request import TokenReissueRequest
from agilicus_api.model.token_revoke import TokenRevoke
from agilicus_api.model.token_scope import TokenScope
from agilicus_api.model.token_validity import TokenValidity
from agilicus_api.model.uri_parameter_rewrite_filter import URIParameterRewriteFilter
from agilicus_api.model.upstream_alias import UpstreamAlias
from agilicus_api.model.upstream_alias_mapping import UpstreamAliasMapping
from agilicus_api.model.upstream_alias_spec import UpstreamAliasSpec
from agilicus_api.model.upstream_group_excluded_entry import UpstreamGroupExcludedEntry
from agilicus_api.model.upstream_group_mapping import UpstreamGroupMapping
from agilicus_api.model.upstream_group_mapping_entry import UpstreamGroupMappingEntry
from agilicus_api.model.upstream_group_mapping_spec import UpstreamGroupMappingSpec
from agilicus_api.model.upstream_group_reconcile import UpstreamGroupReconcile
from agilicus_api.model.upstream_group_reconcile_response import UpstreamGroupReconcileResponse
from agilicus_api.model.upstream_user_identity import UpstreamUserIdentity
from agilicus_api.model.upstream_user_identity_spec import UpstreamUserIdentitySpec
from agilicus_api.model.usage_measurement import UsageMeasurement
from agilicus_api.model.usage_metric import UsageMetric
from agilicus_api.model.usage_metrics import UsageMetrics
from agilicus_api.model.user import User
from agilicus_api.model.user_application_access_info import UserApplicationAccessInfo
from agilicus_api.model.user_application_access_info_status import UserApplicationAccessInfoStatus
from agilicus_api.model.user_attribute import UserAttribute
from agilicus_api.model.user_attributes import UserAttributes
from agilicus_api.model.user_desktop_access_info import UserDesktopAccessInfo
from agilicus_api.model.user_desktop_access_info_status import UserDesktopAccessInfoStatus
from agilicus_api.model.user_file_share_access_info import UserFileShareAccessInfo
from agilicus_api.model.user_file_share_access_info_status import UserFileShareAccessInfoStatus
from agilicus_api.model.user_identity import UserIdentity
from agilicus_api.model.user_identity_update import UserIdentityUpdate
from agilicus_api.model.user_identity_update_spec import UserIdentityUpdateSpec
from agilicus_api.model.user_info import UserInfo
from agilicus_api.model.user_launcher_access_info import UserLauncherAccessInfo
from agilicus_api.model.user_member_of import UserMemberOf
from agilicus_api.model.user_metadata import UserMetadata
from agilicus_api.model.user_metadata_spec import UserMetadataSpec
from agilicus_api.model.user_metrics import UserMetrics
from agilicus_api.model.user_request_info import UserRequestInfo
from agilicus_api.model.user_request_info_spec import UserRequestInfoSpec
from agilicus_api.model.user_request_info_status import UserRequestInfoStatus
from agilicus_api.model.user_resource_access_info import UserResourceAccessInfo
from agilicus_api.model.user_resource_access_info_status import UserResourceAccessInfoStatus
from agilicus_api.model.user_roles import UserRoles
from agilicus_api.model.user_roles_for_an_org import UserRolesForAnOrg
from agilicus_api.model.user_ssh_access_info import UserSSHAccessInfo
from agilicus_api.model.user_ssh_access_info_status import UserSSHAccessInfoStatus
from agilicus_api.model.user_session_identifiers import UserSessionIdentifiers
from agilicus_api.model.user_status_enum import UserStatusEnum
from agilicus_api.model.user_summary import UserSummary
from agilicus_api.model.vnc_connection_info import VNCConnectionInfo
from agilicus_api.model.vnc_password_authentication import VNCPasswordAuthentication
from agilicus_api.model.web_auth_n_enrollment import WebAuthNEnrollment
from agilicus_api.model.web_auth_n_enrollment_answer import WebAuthNEnrollmentAnswer
from agilicus_api.model.web_auth_n_enrollment_spec import WebAuthNEnrollmentSpec
from agilicus_api.model.web_auth_n_enrollment_status import WebAuthNEnrollmentStatus
from agilicus_api.model.well_known_issuer_info import WellKnownIssuerInfo
from agilicus_api.model.whoami_request import WhoamiRequest
from agilicus_api.model.whoami_response import WhoamiResponse
from agilicus_api.model.workload_configuration import WorkloadConfiguration
from agilicus_api.model.x509_certificate import X509Certificate
from agilicus_api.model.x509_certificate_spec import X509CertificateSpec
from agilicus_api.model.x509_certificate_status import X509CertificateStatus
from agilicus_api.model.x509_root_certificate import X509RootCertificate
from agilicus_api.model.x509_root_certificate_spec import X509RootCertificateSpec
from agilicus_api.model.x509_root_certificate_status import X509RootCertificateStatus
from agilicus_api.model.xss_settings import XSSSettings



"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2022.08.11
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import agilicus_api
from agilicus_api.model.auto_create_status import AutoCreateStatus
from agilicus_api.model.kerberos_upstream_status import KerberosUpstreamStatus
globals()['AutoCreateStatus'] = AutoCreateStatus
globals()['KerberosUpstreamStatus'] = KerberosUpstreamStatus
from agilicus_api.model.kerberos_upstream_identity_provider import KerberosUpstreamIdentityProvider


class TestKerberosUpstreamIdentityProvider(unittest.TestCase):
    """KerberosUpstreamIdentityProvider unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testKerberosUpstreamIdentityProvider(self):
        """Test KerberosUpstreamIdentityProvider"""
        # FIXME: construct object with mandatory attributes with example values
        # model = KerberosUpstreamIdentityProvider()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
